==> jcifs-1.1.11.tbz: share/examples/jcifs/runtests.sh <==
#!/bin/sh

JAVA_HOME=/usr/local/java
CLASSPATH=../build:.
PROPERTIES=../../miallen.prp
RUN="${JAVA_HOME}/bin/java -cp ${CLASSPATH} -Djcifs.properties=${PROPERTIES}"

SERVER=rnyxwbf8s5v31
SHARE=pub
WRITE_DIR=test
SRC_DIR=test/Junk
FILE1=test/Junk/tracer/m31_gendler_big.jpg

URL_SHARE=smb://${SERVER}/${SHARE}/
URL_WRITE_DIR=${URL_SHARE}${WRITE_DIR}/

set -x

$RUN AllocInfo ${URL_SHARE}
#$RUN Append ${URL_WRITE_DIR}Append.txt
$RUN AuthListFiles smb://bogus\@${SERVER}/${SHARE}/
$RUN CopyTo ${URL_SHARE}${SRC_DIR}/ ${URL_SHARE}${WRITE_DIR}/CopyTo/
$RUN CreateFile ${URL_WRITE_DIR}CreateFile.txt
$RUN Delete ${URL_WRITE_DIR}CreateFile.txt
$RUN Equals ${URL_WRITE_DIR}CreateFile.txt ${URL_SHARE}${WRITE_DIR}../${WRITE_DIR}/CreateFile.txt
$RUN Exists ${URL_WRITE_DIR}
$RUN FileInfo ${URL_SHARE}${FILE1} 0
$RUN FileOps ${URL_WRITE_DIR}
$RUN FilterFiles ${URL_SHARE}${SRC_DIR}/
$RUN GetDate ${URL_SHARE}${FILE1}
$RUN Get ${URL_SHARE}${FILE1}
$RUN GetType ${URL_SHARE}
$RUN GrowWrite ${URL_WRITE_DIR}GrowWrite.txt
$RUN GetURL ${URL_WRITE_DIR}Append.txt
$RUN HttpURL ${URL_WRITE_DIR}Append.txt
$RUN Interleave ${URL_WRITE_DIR} 3
$RUN IsDir ${URL_SHARE}${SRC_DIR}/
$RUN Length ${URL_SHARE}${FILE1}
$RUN ListFiles ${URL_WRITE_DIR}
$RUN List ${URL_WRITE_DIR}
$RUN ListTypes ${URL_WRITE_DIR}
$RUN Mkdir ${URL_WRITE_DIR}Mkdir
$RUN NodeStatus ${SERVER}
$RUN Put ${URL_WRITE_DIR}Makefile
$RUN Query ${SERVER}
$RUN RenameTo ${URL_WRITE_DIR}Makefile ${URL_WRITE_DIR}Makefile.txt
$RUN SetAttrs ${URL_WRITE_DIR}Makefile.txt FFFF
$RUN SetTime ${URL_WRITE_DIR}Makefile.txt
$RUN SlowWrite ${URL_WRITE_DIR}SlowWrite.txt
$RUN SlowRead ${URL_WRITE_DIR}SlowWrite.txt
$RUN SmbCrawler ${URL_WRITE_DIR} 1000
$RUN T2Crawler ${URL_WRITE_DIR} 3 1000
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 1
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 2 0
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 3 1234

==> jcifs-1.2.13_1.tbz: share/examples/jcifs/runtests.sh <==
#!/bin/sh

JAVA_HOME=/usr/local/java
CLASSPATH=../build:.
PROPERTIES=../../miallen.prp
RUN="${JAVA_HOME}/bin/java -cp ${CLASSPATH} -Djcifs.properties=${PROPERTIES}"

SERVER=ts0
SHARE=tmp
WRITE_DIR=test/
SRC_DIR=test/Junk
FILE1=test/Junk/10883563.doc

URL_SHARE=smb://${SERVER}/${SHARE}/
URL_WRITE_DIR=${URL_SHARE}${WRITE_DIR}

set -x

$RUN SidCacheTest ${URL_WRITE_DIR}
$RUN GetSecurity ${URL_WRITE_DIR}
$RUN SidCrawler ${URL_WRITE_DIR} 5
$RUN InterruptTest ${URL_WRITE_DIR}Append.txt
$RUN AllocInfo ${URL_SHARE}
$RUN Append ${URL_WRITE_DIR}Append.txt
$RUN AuthListFiles smb://bogus\@${SERVER}/${SHARE}/
$RUN CopyTo ${URL_SHARE}${SRC_DIR}/ ${URL_SHARE}${WRITE_DIR}CopyTo/
$RUN CreateFile ${URL_WRITE_DIR}CreateFile.txt
$RUN Delete ${URL_WRITE_DIR}CreateFile.txt
$RUN Equals ${URL_WRITE_DIR}CreateFile.txt ${URL_SHARE}${WRITE_DIR}../${WRITE_DIR}CreateFile.txt
$RUN Exists ${URL_WRITE_DIR}
$RUN FileInfo ${URL_SHARE}${FILE1} 0
$RUN FileOps ${URL_WRITE_DIR}
$RUN FilterFiles ${URL_SHARE}${SRC_DIR}/
$RUN GetDate ${URL_SHARE}${FILE1}
$RUN Get ${URL_SHARE}${FILE1}
$RUN GetType ${URL_SHARE}
$RUN GrowWrite ${URL_WRITE_DIR}GrowWrite.txt
$RUN GetURL ${URL_WRITE_DIR}Append.txt
$RUN HttpURL ${URL_WRITE_DIR} ../Append.txt
$RUN Interleave ${URL_WRITE_DIR} 3
$RUN IsDir ${URL_SHARE}${SRC_DIR}/
$RUN Length ${URL_SHARE}${FILE1}
$RUN ListFiles ${URL_WRITE_DIR}
$RUN List ${URL_WRITE_DIR}
$RUN ListTypes ${URL_WRITE_DIR}
$RUN Mkdir ${URL_WRITE_DIR}Mkdir
$RUN NodeStatus ${SERVER}
$RUN Put ${URL_WRITE_DIR}Makefile
$RUN Query ${SERVER}
$RUN RenameTo ${URL_WRITE_DIR}Makefile ${URL_WRITE_DIR}Makefile.txt
$RUN SetAttrs ${URL_WRITE_DIR}Makefile.txt FFFF
$RUN SetTime ${URL_WRITE_DIR}Makefile.txt
$RUN SlowWrite ${URL_WRITE_DIR}SlowWrite.txt
$RUN SlowRead ${URL_WRITE_DIR}SlowWrite.txt
$RUN SmbCrawler ${URL_WRITE_DIR} 1000
$RUN T2Crawler ${URL_WRITE_DIR} 3 1000
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 1
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 2 0
$RUN TestRandomAccess ${URL_WRITE_DIR}TestRandomAccess.bin 3 1234
